==================
django-bittersweet
==================

.. image:: https://landscape.io/github/acdha/django-bittersweet/master/landscape.svg
   :target: https://landscape.io/github/acdha/django-bittersweet/master
   :alt: Landscape.io Code Quality

.. image:: https://travis-ci.org/acdha/django-bittersweet.png?branch=master
    :target: https://travis-ci.org/acdha/django-bittersweet


Documentation
-------------

This is the limited subset of my `django-sugar <https://github.com/acdha/django-sugar>`_ fork which I
regularly use enough to distribute on PyPI.

See https://django-bittersweet.readthedocs.org/

License
-------

Except for ``bittersweet_json``, all code is released into the public domain.
See `LICENSE <LICENSE>`_

Quickstart
----------

See https://django-bittersweet.readthedocs.org/en/latest/quickstart.html

Running Tests
--------------

You can run the tests against every supported version of Python / Django using ``tox``.

If you're developing new features, run ``python setup.py test``.
